function varargout = gui_dataset(varargin)
%GUI_DATASET display and change data parameters
%
% Works like the other gui_Object widgets
% Take parameters from object, go into wait.
% Get changes after the user pressed ok or cancel.
%
% dataObj - object with parameters
% hData   - handle of widget
%
% 26.12.2005 Elmar,

gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_dataset_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_dataset_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
end



% opening function
function gui_dataset_OpeningFcn(hObject, eventdata, handles, varargin)
global dataObj;

    handles.output = hObject;
    guidata(hObject, handles);
    dataObj = varargin{1};
    indRemoved = find( dataObj.rawData(:,4) == 0 );
    set(handles.output,'name', dataObj.setName);
    
    % names
    set(handles.txt_name,  'String',    dataObj.setName);
    set(handles.txt_xparm, 'String',    dataObj.xName);
    set(handles.txt_yparm, 'String',    dataObj.yName);

    % data points
    if dataObj.numRawPoints >0
        set(handles.txt_globcount, 'String', num2str(dataObj.rawData(:,1)'));
    end
    set(handles.txt_removed, 'String', num2str(dataObj.rawData(indRemoved,1)') );
    
    % activate
    set(handles.pb_average, 'Value',    dataObj.doAverage);
    set(handles.pb_active,  'Value',    dataObj.doUpdate);
    set(handles.pb_showdata,'Value',    dataObj.showDataPoints);

    % plotting
    set(handles.rb_points,  'Value',     dataObj.showSinglePoints);
    set(handles.rb_removed, 'Value',     dataObj.showRemovedPoints);
    set(handles.pb_color,   'BackgroundColor',dataObj.plotColor);
    set(handles.lb_markertype,  'String', dataObj.markerString);
    set(handles.lb_markertype,  'value',  dataObj.markerSelection);
    set(handles.txt_markersize, 'string', num2str(dataObj.markerSize));    

    % errors
    set(handles.rb_errorbars,  'Value',     dataObj.showErrorbars);
    set(handles.rb_errorpatch, 'Value',     dataObj.showErrorPatch);

    
    setappdata(handles.output,'color',dataObj.plotColor);
    
    d = num2cell(dataObj.rawData);
    pos = get(handles.tablepanel,'position');
    t = uitable('position',pos,...
        'ColumnNames',{'glob.', 'x-value', 'y-value', 'selected'},...
        'Data',d);
    
    uiwait();
end


% take userinput and close all
function dataObj = gui_dataset_OutputFcn(hObject, eventdata, handles) 
global dataObj;
    if ishandle(handles.output)
        delete(handles.output);
    end
    drawnow;
end


% get changes
function pb_ok_Callback(hObject, eventdata, handles, selection)
global dataObj;

    % take changes
    if selection == 1

        dataObj.plotColor = getappdata(handles.output,'color');
        
        % removed Globalcounts
        str = get(handles.txt_removed,'String');
        if isempty(str)
            num = [];
        else
            num = str2num( str )';
        end
        dataObj.rawData(:,4) = 1;
        indRemoved = ismember(dataObj.rawData(:,1),num);
        dataObj.rawData(indRemoved,4)  = 0;
        dataObj = dataObj.reselectData;
        
        % get flags
        dataObj.doAverage        = logical( get(handles.pb_average,'Value') );
        dataObj.showSinglePoints = logical( get(handles.rb_points, 'Value') );
        dataObj.showRemovedPoints= logical( get(handles.rb_removed,'Value') );
        dataObj.doUpdate         = logical( get(handles.pb_active, 'Value') );
        dataObj.showDataPoints   = logical( get(handles.pb_showdata,'Value') );
        dataObj.showErrorbars    = logical( get(handles.rb_errorbars,'Value') );
        dataObj.showErrorPatch   = logical( get(handles.rb_errorpatch,'Value') );


        dataObj.setName          = get(handles.txt_name,'string');

        dataObj.markerString    = get(handles.lb_markertype,'String');
        dataObj.markerSelection = get(handles.lb_markertype,'Value');
        
        v = str2num(get(handles.txt_markersize,'String'));
        if isempty(v) || v<=0
            warndlg(['Wrong entry for marker size: ',get(handles.txt_markersize,'String')],'gui-error');
            v = 6;
        end
        dataObj.markerSize = v;
        
    end
	uiresume(handles.output);

end

% colors
function pb_color_Callback(hObject, eventdata, handles)
    col = uisetcolor([0,0,0]);
    setappdata(handles.output,'color',col);
    set(handles.pb_color,'Backgroundcolor',col);
end

