function [legendString, xName, yName, hplot] = plotData(obj,varargin)
%PLOT
% plots data to haxes
% elmar, 12.8.08


    %*********************************************
    % Check inputs
    %*********************************************
    switch nargin 
        case 0
            disp('Could not plot data object.');
            return;
        case 1    
           haxes = gca(figure);            
           doEndPoint = false;
        case 2
           if ishandle(varargin{1})
               haxes = varargin{1};
           else
               haxes = gca(figure);
           end
           doEndPoint = false;
        case 3
           doEndPoint = varargin{2};
           if ishandle(varargin{1})
               haxes = varargin{1};
           else
               haxes = gca(figure);
           end
    end

    %*********************************************
    % Check points and names
    %*********************************************
    
    % if there are no points -> do no plot
    if obj.numSelPoints<=0 || ~obj.showDataPoints
        legendString = '';          % new legendstring
        hplot        = [];          % handle for plotobject
        xName        = '';
        yName        = '';
        return;
    end

    % fix names
    xName = obj.xName;
    yName = obj.yName;
    
    % legend
    minGlobCount = min( obj.selectedData(:,1));
    maxGlobCount = max( obj.selectedData(:,1));  
    legendString = ['#',num2str(minGlobCount),' - #',num2str(maxGlobCount),'  ',obj.setName];
    
    % set marker
    if obj.markerSelection <= size(obj.markerString,1)
        marker = char( obj.markerString(obj.markerSelection) );
    else
        marker = 'o';
    end

    %**********************************************
    % do the plotting 
    %**********************************************
    hold(haxes,'on');
    
    %******************
    % average plot
    %******************    
    if obj.doAverage
        if obj.showErrorbars
            h1 = errorxy(haxes, ...
                [obj.averagedData(:,1), obj.averagedData(:,2), obj.averagedData(:,3)], ...
                'markersize', obj.markerSize,...
                'linewidth',2,...
                'marker',obj.markerString{obj.markerSelection} , ...
                'markerfacecolor', obj.plotColor, ...
                'patch',obj.showErrorPatch, ...
                'tag', 'averaged' ...
            );
            hplot = h1(1);
        else
            hplot = plot(haxes, ...
                obj.averagedData(:,1), obj.averagedData(:,2),'o', ...
                'markersize', obj.markerSize,...
                'linewidth',2,...
                'marker',obj.markerString{obj.markerSelection} , ...
                'markerfacecolor', obj.plotColor, ...
                'tag', 'averaged' ...
            );
        end
    
        % single points
        if obj.showSinglePoints
            hold(haxes,'on');            
            hplot = plot(haxes, ...
                obj.selectedData(:,2), obj.selectedData(:,3), marker,...
                'markersize', obj.markerSize*0.7,...
                'markerfacecolor', [1,1,1], ...
                'markeredgecolor', obj.plotColor./2, ...                
                'tag', 'single' ...
            );
        end
    else
        
        %******************
        % normal plot
        %******************
        hplot = plot(haxes, ...
            obj.selectedData(:,2),obj.selectedData(:,3),marker,...
            'markersize', obj.markerSize,...
            'linewidth',2, ...
            'marker',obj.markerString{obj.markerSelection} , ...
            'markerfacecolor', obj.plotColor, ...
            'markeredgecolor', obj.plotColor./2, ...                
            'tag','normal' ...
        );
    end
    
    %******************************
    % show removed points
    %******************************    
    if obj.showRemovedPoints
        hold(haxes,'on');            
        ind = find( obj.rawData(:,4) == 0 );
        plot(haxes, ...
            obj.rawData(ind,2),obj.rawData(ind,3),marker,...
            'markersize', obj.markerSize*0.8,...
            'linewidth',2, ...
            'tag','removedpoints',...
            'Color', [1,1,1]-([1,1,1]-obj.plotColor)/3 ...
        );
    end
    
    %*********************
    % last point
    %*********************
    if doEndPoint && ~isempty(obj.selectedData(:,2))
        hold(haxes,'on'); 
        plot(haxes, ...
            obj.selectedData(end,2),obj.selectedData(end,3),'*',...
            'markersize',12,...
            'marker','*', ...
            'linewidth',2, ...
            'Color', obj.plotColor./2,  ...
            'tag','lastpoint' ...
        );
    end
    
    hold(haxes,'off');
end

