classdef networkClass <  handle 

    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Network class. It stores the IPs and ports, the current 
% status and provides the opportunity to start and stop
% the connection.
%
% Elmar, 8.11.05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

properties

    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % IPs / Ports
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    analysisIP    = 'localhost';      % ip of analysis computer
    analysisPort  = 8010;             % port on camera computer
    localIP       = 'localhost';      % local ip
    localPort     = 8011;             % local port for camera computer
    status        = 0;                % 0-ok, connection error

    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % Objects
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    udpObj        = [];

end


methods
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % Constructor
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    function obj = networkClass
        %construct obj;
    end


    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % display
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    function disp(obj)
        disp('Network object parameters:');
        fprintf('analysisIP     = %s\n',num2str(obj.analysisIP));
        fprintf('analysisPort   = %s\n',num2str(obj.analysisPort));
        fprintf('localIP        = %s\n',num2str(obj.localIP));
        fprintf('localPort      = %s\n',num2str(obj.localPort));
        obj.udpObj
    end


    %%%%%%%%%%%%%%%%%%%%%%%%%
    % open udpObj
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    function obj = openUdp(obj)
        try
           fopen( obj.udpObj );
        catch
           s = lasterror;
           disp(['Could not open network connection:  ','',s.message]);
           return;
        end
        disp(['Network port is open.']);
    end
    

    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % stop udp connection
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    function obj = closeUdp(obj)
        try
            fclose(obj.udpObj);
        end
        disp('Closing upd-network sequence');
    end

    function obj = clearUdp(obj)
        try
            delete(obj.udpObj);
            clear obj.udpObj;
            disp('Clearing upd-connection.');
        catch
            disp(lasterr);
       end
    end
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%
    % setup udpObj
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    function obj = initUdp(obj)
        % clean up
         oldInstr = instrfind;
         if ~isempty(oldInstr)
             try
                 delete(oldInstr);
                 clear oldInstr;
             catch
                 disp(lasterr);
             end
         end
       
        % create connection socket
         obj.udpObj = udp('localhost', 'localPort',obj.localPort);
         obj.udpObj.DatagramReceivedFcn = @recievePackage;
         disp('Starting upd-network');
        
    end

    
end    
    
end


