classdef sequenceClass < handle
%SEQUENCECLASS background class for gui_sequence    
% It contains the data and fit Objects and 
% a couple of flags.
% There are a few functions to access all data+fit Objects
% and most important there is the plotting function
% for the sequence object.
%
% Elmar, 25.10.05
% ajusted, 1.5.06 Elmar  

properties
    %*****************************
    % data
    %*****************************
    controlParameters = paramClass;
    calcParameters    = paramClass;
    
    %*****************************
    % flags
    %*****************************
    doUpdate  = true;        % update the block??
    numSeq    = 1;           % internal number for block 1,2


    %*****************************
    % data
    %*****************************
    listData  = {};
    numData   = 4;     % number of datasets
    listFits  = {};
    numFits   = 4;     % number of fits

    %******************************
    % plot
    %******************************    
    colList   = [ [0,0,1];[1,0,0];[0,1,0];[0,0,0] ];
    logx      = false;
    logy      = false;
    hGUI      = [];
    
end


methods

%*****************************
% Constructor
%*****************************
function obj = sequenceClass
    %construct obj;
    
    for i=1:4
        obj.listData{i} = dataClass('','');
        obj.listData{1}.plotColor = obj.colList(i,:); 
    end
    
    obj.listData{1}.plotColor = [0,0,1];        % init colors
    obj.listData{2}.plotColor = [1,0,0];
    obj.listData{3}.plotColor = [0,1,0];
    obj.listData{4}.plotColor = [0,0,0];

    for i=1:4
        obj.listFits{i} = fitClass;
    end
    
    obj.listFits{1}.plotColor = [0 0 1];
    obj.listFits{2}.plotColor = [1 0 0];
    obj.listFits{3}.plotColor = [0 0.5 0.2];
    obj.listFits{4}.plotColor = [0 0 0];
    
    obj.listFits{1}.dataSet = [true false false false];
    obj.listFits{2}.dataSet = [false true false false];
    obj.listFits{3}.dataSet = [false false true false];
    obj.listFits{4}.dataSet = [false false false true];
    
end


%***************************************
% Add and remove Datapoints/Fits
%***************************************



%*****************************
% remove points in intervall
%*****************************
function obj = removePoints(obj,xmin,xmax,ymin,ymax)
     for num=1:obj.numData
         %if obj.listData{num}.doUpdate;
         if obj.listData{num}.showDataPoints
             obj.listData{num} = obj.listData{num}.removePoints(xmin,xmax,ymin,ymax);
         end
     end
end


%*****************************
% add data points
%*****************************
function obj = addDataPoints(obj)
    for num = 1:obj.numData
        if obj.listData{num}.doUpdate
            obj.listData{num} = obj.listData{num}.addDataParameter(obj.controlParameters,obj.calcParameters);
        end
    end
end

%*****************************
% update data objects
%*****************************
function obj = updateData(obj,list)
     if ~exist('list','var') || list==0
         list = 1:obj.numData;
     end
     for num = list
         if obj.listData{num}.doUpdate
             obj.listData{num} = obj.listData{num}.updateData;
         end
     end
end

%*****************************
% clear fit
%*****************************
function obj = clearFits(obj,list)
    if list==0
        list = 1:obj.numFits;
    end
    for num = list
        obj.listFits{num} = obj.listFits{num}.clearFit(obj.hGUI.plotAxes);
    end
end

%*****************************
% update fits
%*****************************
function obj = updateFits(obj,list)     % 0 - for all fits
    if list==0
        list = 1:obj.numFits;       
    end
    for num = list
         if obj.listFits{num}.doFit
            obj.listFits{num} = obj.listFits{num}.runFit(obj,obj.hGUI.plotAxes);
         end
    end
end



%*************************************************
% Connection to gui
%*************************************************


%*************************
% set new parameter list
%*************************
function obj = updateParameters(obj,mode,controlP,calcP)
    
    % mode 0 - analysis call, change lists & parameters
    % mode 1 - activation from gui, just update
    if mode==0 && exist('controlP','var') && exist('calcP','var')
        obj.calcParameters    = calcP;
        obj.controlParameters = controlP;
    end
    obj.updateParametersGUI(mode);
    
    if mode==0    
        obj = obj.addDataPoints;
    end
    obj.updatePlot;
    obj = obj.updateFits(0);
    obj.updatePlotFits;
    obj.updateFitResults;
end

   
function updateParametersGUI(obj,mode)

    if isempty(obj.hGUI)
        return;
    end
    
    % strings with at least one line
    str1 = obj.controlParameters.mkParamString;
    str2 = obj.calcParameters.mkParamString;
    if isempty(str1); str1{1} = '---------------------'; end;
    if isempty(str2); str2{1} = '---------------------'; end;
    
    % you need to prevent that a non existing 
    % item in a listbox is selected ....
    for i=1:obj.numData
        if obj.listData{i}.doUpdate
           eval(['setListBoxEntry(obj.hGUI.lb_paramX',num2str(i),',str1,obj.listData{',num2str(i),'}.xName,',num2str(i),');']);
           eval(['setListBoxEntry(obj.hGUI.lb_paramY',num2str(i),',str2,obj.listData{',num2str(i),'}.yName,',num2str(i),');']);
        end
    end
    drawnow;
    
    %*************************************
    % helper function for listboxes
    %*************************************
    function setListBoxEntry(h_listbox, new_string, name, num )
        oldPosition = get(h_listbox, 'Value');          % get old positions
        oldList     = get(h_listbox, 'String');
        oldSize     = size(oldList,1);
        newSize     = size(new_string,1);               % new size
        set( h_listbox, 'Backgroundcolor', min([1,1,1], obj.listData{num}.plotColor + [.85,.85,.85]));           

       % check if nothing has changed, or changes are save
       if (newSize >= oldSize) && strcmp(name,new_string{oldPosition})
           set( h_listbox, 'String', new_string);            
           return;
       end

       % look for old name in new string
       nindex = find( strcmp(new_string,name),1,'first');              
       if ~isempty(nindex)
            set( h_listbox, 'String', new_string);            
            set( h_listbox, 'Value',  nindex);
       else
            if mode>0
                set( h_listbox, 'String', new_string);            
                set( h_listbox, 'Value',  1);                
            else
                % could not find old name
                set( h_listbox,'Backgroundcolor', [0.5,0.5,0.5]);
            end
        end
    end     
end



%*************************
% write fit results to gui
%*************************
function updateFitResults(obj)
    for i=1:obj.numFits
        if obj.listFits{i}.doFit 
           eval(['set(obj.hGUI.txt_',num2str(i),',''String'',''',obj.listFits{i}.smallStr,''',''FontSize'',9);']);
        end
    end
end



end

end
