function updatePlot(obj,hax)
%UPDATEPLOT
% plot for sequence object
% Elmar 8.8.08


    %*************************
    % storage variables
    %*************************    
    strX = {''};    % string x
    strY = {''};    % string x
    legData  = {};  % legend  
    hplots   = [];  % plothandle

    %*************************
    % clear axes
    %*************************  
    if ~exist('hax','var')
        h_axes = obj.hGUI.plotAxes;
    else
        h_axes = hax;
    end
    cla(h_axes);
    
    %**************************
    % cycle datasets and plot
    %**************************
    for i=1:obj.numData
        [legData{i}, strX{i},strY{i},v] = obj.listData{i}.plotData(h_axes, true);
        if ~isempty(v)
            hplots = [hplots, v];
        end
    end
    
    %**********************    
    % fix legend
    %**********************
    legData( strcmp(legData, '') ) = [];    % tidy up
    if ~isempty(hplots)
        %axes(h_axes);
        legend(hplots,legData);
    end

    
    %**************************
    % fix grid and labels
    %**************************    
    set(h_axes,'XGrid','on');
    set(h_axes,'YGrid','on');
   	xlabel(h_axes,['\bf ',fixString(strX)]);    
   	ylabel(h_axes,['\bf ',fixString(strY)]);    

    %**************************
    % log scale?
    %**************************    
    if obj.logx
        set(h_axes,'XScale','log'); 
    else
        set(h_axes,'XScale','linear');
    end
    if obj.logy
        set(h_axes,'YScale','log'); 
    else
        set(h_axes,'YScale','linear'); 
    end


    
    % clean up double and empty words
    function s = fixString(str)
        s = [];    
        str(strcmp(str,'')) = [];   
        for i=1:length(str); 
            if ~sum(strcmp(s,str{i}))
                if isempty(s)
                    s = str{i};
                else
                    s = [s,' / ',str{i}];
                end
            end
        end
    end

end