function varargout = gui_fitting(varargin)
%*************************************************************************
% gui_fitting.m
% 
% GUI to edit everything connect to a fit
% - active
% - type of fit
% - use datasets ...
% - use parameters
% 
% Elmar, 4.5.06
% Checked and formated
%*************************************************************************
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_fitting_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_fitting_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
end



%******************************************************
% opening function
%
% checks input and initialises widget values
%******************************************************
%function gui_fitting_OpeningFcn(hObject, eventdata, handles, selection, num )
function gui_fitting_OpeningFcn(hObject, eventdata, handles, fObj )
global fitObj;

    handles.output = hObject;
    guidata(hObject, handles);
    fitObj = fObj;
    
    %*****************
    % set gui init
    %*****************
    set(handles.lb_fitname,'String',fitObj.fitName);    

    set(handles.rb_active, 'Value', fitObj.doFit );
    set(handles.lb_fitname,'Value', fitObj.fitNumber );
    set(handles.pb_color,  'backgroundcolor', fitObj.plotColor); 
            
    text(0.01,0,fitObj.bigStr,'parent', handles.ax_fit,'VerticalAlignment','top','FontWeight','normal' );
    setappdata(handles.output,'plotColor',fitObj.plotColor);
            
    set(handles.rb_data1, 'value', fitObj.dataSet(1));
    set(handles.rb_data2, 'value', fitObj.dataSet(2));            
    set(handles.rb_data3, 'value', fitObj.dataSet(3));            
    set(handles.rb_data4, 'value', fitObj.dataSet(4));   
            
    set(handles.txt_p1, 'String', num2str(fitObj.param(1) ));
    set(handles.txt_p2, 'String', num2str(fitObj.param(2) ));
    set(handles.txt_p3, 'String', num2str(fitObj.param(3) ));            

    set(handles.rb_adopt,'Value', fitObj.adoptPoints);

    pos = get(handles.tablepanel,'position')+[8,38,0,0];
    if isempty( fObj.tabEntries )
        fObj.tabEntries = {'-','-','-'};
    end
    t = uitable('position',pos,...
        'ColumnNames',{'parameter', 'value', 'error'},...
        'Data',fObj.tabEntries,...
        'ColumnWidth',90 ...
        );
    drawnow;
    
    % wait for user
    uiwait(hObject);
end


%*****************
% close function
%*****************
function fitObj = gui_fitting_OutputFcn(hObject, eventdata, handles)
global fitObj;
    delete(handles.output);
    drawnow;
end


%*****************
% change color
%*****************
function pb_color_Callback(hObject, eventdata, handles)
    col = getappdata(handles.output,'plotColor');
    col = uisetcolor(col,'Colorselection');
    set(handles.pb_color,'BackgroundColor',col);
    setappdata(handles.output,'plotColor',col);
end


%*****************************************
% react on ok or cancel button
%*****************************************
function pb_ok_Callback(hObject, eventdata, handles, ok)
global fitObj;

    %*****************
    % take changes
    %*****************
    if ok == 1
        fitObj.doFit     = logical( get(handles.rb_active,'Value') );
        fitObj.plotColor  = getappdata(handles.output,'plotColor');

        fitObj.dataSet(1) = logical(get(handles.rb_data1,'value'));
        fitObj.dataSet(2) = logical(get(handles.rb_data2,'value'));
        fitObj.dataSet(3) = logical(get(handles.rb_data3,'value'));
        fitObj.dataSet(4) = logical(get(handles.rb_data4,'value'));

        p1 = str2num(get(handles.txt_p1,'String'));
        if ~isempty(p1)
            fitObj.param(1) = p1;
        end
        p2 = str2num(get(handles.txt_p2,'String'));
        if ~isempty(p2)
            fitObj.param(2) = p2;
        end
        p3 = str2num(get(handles.txt_p3,'String'));
        if ~isempty(p3)
            fitObj.param(3) = p3;
        end
        fitObj.adoptPoints = logical(get(handles.rb_adopt,'value'));
    end
    
    %***************************
    % continue program flow
    %***************************    
    uiresume(handles.output);
end


