function ret = errorxy(haxes, data, varargin)
%----------------------------------------------------------------------------
% errorxy function         Plot graphs with error bars on both axes.
%                          (This is an improved version of errorxy_o.m).
%                          original  
%                          By : Eran O. Ofek               March 2004
%                          I changed it quite a lot to fit our needs
%                          Elmar Haller,                   August 2008
% 
%
%----------------------------------------------------------------------------

Ndots = 450;    % approximate number of dots

% check input
Nvarg = length(varargin);
if (0.5.*Nvarg~=floor(0.5.*Nvarg)),
    error('Illegal number of input arguments');
end

if ~exist('data','var')
   disp('No data input.');
   return;
end

if ~exist('haxes','var') || ~ishandle(haxes)
    haxes = gca;
end

%***************************
% set default values
%***************************

% columns
colx  = 1;
coly  = 2;
colxe = [NaN, NaN];
colye = [3 3];

% markers
marker   = 'o';
marksize = 6;
markerfacecolor = NaN;
markeredgecolor = NaN;
linewidth = 1;


% errorbars
eb_color        = NaN;
eb_line         = '-';
eb_width        = 0.5;
eb_length       = 2;
do_patch        = 0;

% all arguments not used directly
argsUnknown = [];
argsCounter = 1;

for j=1:2:Nvarg-1,
    switch lower(varargin{j})
       case 'colx'
          colx        = varargin{j+1};
       case 'coly'
          coly        = varargin{j+1};
       case 'colxe'
          colxe       = varargin{j+1};
       case 'colye'
          colye       = varargin{j+1};
       case 'marker'
          marker      = varargin{j+1};
       case 'marksize'
          marksize    = varargin{j+1};
       case 'markerfacecolor'
          markerfacecolor = varargin{j+1};
       case 'markeredgecolor'
          markeredgecolor = varargin{j+1};
       case 'linewidth'
            linewidth = varargin{j+1};
       case 'eb_color'
          eb_color    = varargin{j+1};
       case 'eb_line'
          eb_line     = varargin{j+1};
       case 'eb_width'
          eb_width    = varargin{j+1};
       case 'eb_length'
          eb_length   = varargin{j+1};
        case 'patch'
          do_patch    =  varargin{j+1};
       otherwise
           argsUnknown{argsCounter}   = varargin{j};
           argsUnknown{argsCounter+1} = varargin{j+1};
           argsCounter                = argsCounter+2;
      end
end
   
%******************
% fix parameters
%******************
if isnan(markerfacecolor)
    markerfacecolor = [0,0,1];
end
if isnan(markeredgecolor)
    markeredgecolor = markerfacecolor*0.5;
end
if isnan(eb_color)
    eb_color = markeredgecolor;
end



if (length(colxe)==1),
    colxe = [colxe, colxe];
end
if (length(colye)==1),
    colye = [colye, colye];
end
   
nPlot = get(haxes,'nextplot');
hold(haxes,'on');

%******************
% spans
%******************
spanX = max(data(:,colx)) - min(data(:,colx));
spanY = max(data(:,coly)) - min(data(:,coly));
edgeX = spanX.*eb_length./Ndots;
edgeY = spanY.*eb_length./Ndots;
   
   
   
%******************
% plot data points
%******************

N = size(data,1);


for j=1:1:N
    
    % plot Y error bars
    if (isnan(colye(1))==0),
        Hyerr(j) = plot(haxes, ...
                    [data(j,colx); data(j,colx)],...
                    [data(j,coly)-data(j,colye(1)); data(j,coly)+data(j,colye(2))],...
                     '-');
        set(Hyerr,'color',eb_color,...
                  'LineStyle',eb_line,...
                  'LineWidth',eb_width ...
        );

        % errorbar edge
        if (eb_length>0)
            % lower edge
            Heyel(j) = plot(haxes,...
                         [data(j,colx)-edgeX; data(j,colx)+edgeX],...
                         [data(j,coly)-data(j,colye(1)); data(j,coly)-data(j,colye(1))],...
                '-');
            set(Heyel,'Color',eb_color,...
                      'LineStyle',eb_line,...
                      'LineWidth',eb_width ...
            );
            % upper edge
            Heyeu(j) = plot(haxes, ...
                         [data(j,colx)-edgeX; data(j,colx)+edgeX],...
                         [data(j,coly)+data(j,colye(2)); data(j,coly)+data(j,colye(2))],...
                        '-');
            set(Heyeu,'Color',eb_color,...
                      'LineStyle',eb_line,...
                      'LineWidth',eb_width ...
            );
        end
    end

    % plot X error bars
    if (isnan(colxe(1))==0),
        Hxerr(j) = plot(haxes, ...
                    [data(j,colx)-data(j,colxe(1)); data(j,colx)+data(j,colxe(2))],...
                    [data(j,coly); data(j,coly)],...
                    '-');
        set(Hxerr,'Color',eb_color,...
                  'LineStyle',eb_line,...
                  'LineWidth',eb_width ...
            );
        
        % edge
         if (eb_length>0)
             
            % lower edge
            Hexel(j) = plot(haxes, ...
                        [data(j,colx)-data(j,colxe(1)); data(j,colx)-data(j,colxe(1))],...
                        [data(j,coly)-edgeY; data(j,coly)+edgeY],...
                        '-');
            set(Hexel,'Color',eb_color,...
                'LineStyle',eb_line,...
                'LineWidth',eb_width ...
            );
            % upper edge
            Hexer(j) = plot(haxes, ...
                        [data(j,colx)+data(j,colxe(2)); data(j,colX)+data(j,colxe(2))],...
                        [data(j,coly)-edgeY; data(j,coly)+edgeY],...
                        '-');
            set(Hexer,'Color',eb_color,...
                'LineStyle',eb_line,...
                'LineWidth',eb_width ...
            );
        end
    end

    % plot points
    Hpoint(j) = plot(haxes,...
                    data(j,colx),data(j,coly),'o',...
                    'linewidth',linewidth,...
                    'marker',marker,...
                    'markerfacecolor',markerfacecolor,...
                    'markeredgecolor',markeredgecolor ...
                );
    if ~isempty(argsUnknown)
       set(Hpoint,argsUnknown{1:end});
    end
    

end

if do_patch
    lData  = data(:,coly)-data(:,colye(1));
    uData = data(:,coly)+data(:,colye(2));
    %xrange = [data(:,colx); flipud(data(:,colx))];
    %yrange = [lData;flipud(uData)];
%    Hpatch = patch( xrange,yrange,markeredgecolor, ...
%                   'FaceAlpha',0.5, ...
%                   'EdgeColor',markeredgecolor,'parent',haxes );
    
    xx1 = linspace(data(1,colx),data(end,colx),200);
    xx2 = linspace(data(end,colx),data(1,colx),200);
    y1  = lData;
    y2  = flipud(uData);
    
    yy1 = spline(data(:,colx),y1,xx1);
    yy2 = spline(flipud(data(:,colx)),y2,xx2);
    Hpatch = patch( [xx1,xx2],[yy1,yy2],markeredgecolor, ...
                   'FaceAlpha',0.2, ...
                   'EdgeColor',markeredgecolor,'parent',haxes,'linestyle','none');

end


% return hold to riginal state
set(haxes,'NextPlot',nPlot);
hold(haxes,'off');
ret = Hpoint;

end
