classdef fitGauss < fitClass
%FITLINEAR class for quadratic fitting of datapoints.
% childclass of @fitClass
%
% Elmar, 2.4.2007



methods

    %***************************
    % Init fitting stuff
    %***************************
    function obj = initFitting(obj)
    
        % init fit
        obj.fType    = fittype('gauss1' );   
        obj.fOpts{1} = fitoptions(obj.fType);
        obj.fType    = fittype('a*exp(-((x-b)/c)^2)+d',...
                               'independent', 'x', ...
                               'dependent', {'a','b','c','d'} );        
        obj.fitName  = 'Gauss';  % internal name
        obj.fitNumber= 1;        % index given by gui
        obj.minPoints= 4;        % minimum number of datapoints

    end

    
    %***************************
    % calc start points
    %***************************
    function obj = startPrePoints(obj, haxes)
        xl = xlim(haxes);
        yl = ylim(haxes);
        x = xl(1);
        y = yl(1);
        dx = xl(2)-xl(1);
        dy = yl(2)-yl(1);
        obj.prePoints(1,:) = [x+dx*0.5 y+dy*0.9];
        obj.prePoints(2,:) = [x+dx*0.7 y+dy*0.3];
        obj.prePoints(3,:) = [x+dx*0.3 y+dy*0.1];        
    end


    %***************************
    % calc start points
    %***************************
    function obj = getStartPoints(obj,haxes)
        if obj.adoptPoints && ~isempty(obj.fResult)
            obj.fOpts{1}.StartPoint = [obj.fResult.a obj.fResult.b obj.fResult.c obj.fResult.d ];
        else
            % start points [p1 p2], from prepoints
            if isempty(obj.prePoints)
                  obj = obj.startPrePoints(haxes);
            end
                d = obj.prePoints(3,2);
                a = obj.prePoints(1,2)-d;
                b = obj.prePoints(1,1);
                c = (obj.prePoints(2,1)-b)/sqrt(abs(log( (obj.prePoints(2,2)-d)/a )));
                obj.fOpts{1}.StartPoint = [a b c d];
        end
    end
    
    function [xrange,yrange] = calcDataPoints(obj,dx,prePoints)
        d = prePoints(3,2);
        a = prePoints(1,2)-d;
        b = prePoints(1,1);
        c = (prePoints(2,1)-b)/sqrt(abs(log( (prePoints(2,2)-d)/a )));
        xrange = linspace(dx(1),dx(2),50);           
        yrange = a*exp(-((xrange-b)/c).^2)+d;
    end

    
%******************************************
% calc prePoints from old fit results
% (to set new prePoints)
%******************************************
function obj = last2PrePoints(obj, haxes)
    if isempty(obj.fResult)
        obj = obj.startPrePoints(haxes);
        return;
    end
    x = xlim(haxes);
    dx = x(2)-x(1);

    x = [x(1)+dx*0.5 x+dx*0.7 x+dx*0.3];
    y = obj.fResult.a*exp(-((x-obj.fResult.b)/ obj.fResult.c).^2)+ obj.fResult.d;
end


    %***************************
    % write output to strings
    %***************************
    function obj = createOutput(obj)
        fSigma  = confint(obj.fResult,0.68);
        deltaA  = max( abs(fSigma(:,1)- obj.fResult.a) );
        deltaB  = max( abs(fSigma(:,2)- obj.fResult.b) );
        deltaC  = max( abs(fSigma(:,3)- obj.fResult.c) );
        deltaD  = max( abs(fSigma(:,4)- obj.fResult.d) );

    
        obj.bigStr = {'\bfModel: f(x) = a*exp(-((x-b)/c)^2)+d',...
                  '\rmno parameters unused'};
        obj.smallStr = sprintf('%-2.2e',obj.fResult.c);
        obj.tabEntries = {'a', num2str(obj.fResult.a), num2str(deltaA); ...
                          'b', num2str(obj.fResult.b), num2str(deltaB); ...
                          'c', num2str(obj.fResult.c), num2str(deltaC); ...
                          'd', num2str(obj.fResult.d), num2str(deltaD); ...
                          '','','';...
                          'xi2',num2str(obj.gof.rsquare),''};
        
    end

    
end

end
