classdef fitLorentz < fitClass
%FITLINEAR class for lorentzian fit of datapoints.
% childclass of @fitClass
%
% Elmar, 2.4.2007


methods

    %***************************
    % Init fitting stuff
    %***************************
    function obj = initFitting(obj)
        % init fit
        obj.fType    = fittype(['a/(a^2+(x-b)^2)+d'], ...
                            'independent', 'x', ...
                            'dependent', {'a','b','d'} );        
        obj.fOpts{1} = fitoptions('Method','NonlinearLeastSquares');
        obj.fitName  = 'Lorentz';  % internal name
        obj.fitNumber= 1;        % index given by gui
        obj.minPoints= 4;        % minimum number of datapoints
        obj.doPreSetting  = false;        
    end

    
    %***************************
    % calc start points
    %***************************
    function obj = startPrePoints(obj, haxes)
        dx = xlim(haxes);
        dy = ylim(haxes);
        obj.prePoints(1,:) = [dx(1)*1.1 dy(1)*1.1];
        obj.prePoints(2,:) = [dx(2)*0.3 dy(2)*0.3];
        obj.prePoints(3,:) = [dx(2)*0.6 dy(2)*0.6];        
    end


    %***************************
    % calc start points
    %***************************
    function obj = pre2StartPoints(obj)
        d = obj.prePoints(3,2);
        a = obj.prePoints(1,2)-d;
        b = obj.prePoints(1,1);
        obj.fOpts{1}.StartPoint = [a b d];
    end

    function yrange = calcDataPoints(obj,xrange,prePoints)
        d = prePoints(3,2);
        a = prePoints(1,2)-d;
        b = prePoints(1,1);
        yrange = a./(a^2+(xrange-b).^2)+d;
    end



    
    %***************************
    % write output to strings
    %***************************
    function obj = createOutput(obj)
%         err       = confint(obj.fResult);
%         max_err_v = max( err(:,2)-obj.fResult.sig_v );
%         max_err_0 = max( err(:,1)-obj.fResult.sig_0 );
% 
%         Temp       = 0.016 * obj.fResult.sig_v*obj.fResult.sig_v;
%         Temp_error = 0.016 * obj.fResult.sig_v*max_err_v;
% 
%         
%        obj.bigStr = {  ...
%             ['\bf  Model: \sigma_t = \surd ( \sigma_0^2 + (\sigma_v^2 * (TOF+',num2str(obj.param(1)),')^2 ))'],' ', ...
%             sprintf('  \\sigma_0 = %3.1f \\pm %3.1f \\mum',    obj.fResult.sig_0,max_err_0),' ', ...
%             sprintf('  \\sigma_v = %3.1f \\pm %3.1f \\mum/ms', obj.fResult.sig_v,max_err_v),' ',...
%             sprintf('  T  = %3.5f \\pm %3.5f \\muK', Temp, Temp_error) ...
%         };            
    end

    
end

end
