classdef fitSpline < fitClass
%FITSPLINE class for simple spline
%
% childclass of @fitClass
%
% Elmar, 5.4.2007

properties
    maxPoint = NaN;   
    minPoint = NaN;   
end


methods

    %***************************
    % Init fitting stuff
    %***************************
    function obj = initFitting(obj)
    
        % init fit
        obj.fType    = fittype('cubicspline' );   
        obj.minPoints     = 3;
        obj.fitName       = 'Qubic Spline';  % internal name        
        obj.doPreSetting  = false;
        obj.fOpts{1}      = fitoptions(obj.fType);
    end

    
    function obj = pre2StartPoints(obj)
    end
   
    %***************************
    % write output to strings
    %***************************
    function obj = createOutput(obj)
        % prob. ms used calc freq.
        obj.bigStr = {'\bfModel: Qubic Spline'};

        obj.smallStr = sprintf('---');
    end


%***************************
% runFit
%***************************
function obj = runFit(obj, seqObj, haxes)

    % get data
    xdata = [];
    ydata = [];
	for i=1:seqObj.numData
        if obj.dataSet(i) && seqObj.listData{i}.numSelPoints > 0
            xdata = [xdata; seqObj.listData{i}.selectedData(:,2)];
            ydata = [ydata; seqObj.listData{i}.selectedData(:,3)];
        end
    end

    % check datasize
    if size(xdata,1)<obj.minPoints
        disp('Datasize too small.');
        return;
    end
    
    % calc mean
    avData = mgroup([ xdata, ydata,  ydata],['mean';'stdd']);
    
    obj.maxPoint = max(avData(:,1));
    obj.minPoint = min(avData(:,1));
    
    try 
        [obj.fResult,obj.gof] = fit( avData(:,1), avData(:,2), obj.fType, obj.fOpts{1});
        obj = obj.createOutput;
    catch
        disp(['Problems during fiting']);
        disp(lasterr);
        disp('');
    end

end

%***************************
% plot fit
%***************************
function obj = plotFit(obj,haxes)
    if ~isempty( obj.fResult )
        dx = xlim(haxes);
        if isnan(obj.maxPoint) || isnan(obj.minPoint)
           obj.minPoint = dx(1);            
           obj.maxPoint = dx(2);
        end
        xrange = linspace(obj.minPoint,obj.maxPoint,500);
        obj.handle = plot(haxes,xrange,obj.fResult(xrange), ...
                         'color',obj.plotColor, ...
                         'linewidth',1.5);
    end
end


end
end
