classdef fitSplineNearest < fitClass
%FITSPLINE class for simple spline
%
% childclass of @fitClass
%
% Elmar, 5.4.2007


methods

    %***************************
    % Init fitting stuff
    %***************************
    function obj = initFitting(obj)
    
        % init fit
        obj.fType    = fittype('nearestinterp' );   
        obj.minPoints     = 3;
        obj.fitName       = 'SplineNearest';  % internal name        
        obj.doPreSetting  = false;
        obj.fOpts{1}      = fitoptions(obj.fType);
    end

    
    function obj = pre2StartPoints(obj)
    end
   
    %***************************
    % write output to strings
    %***************************
    function obj = createOutput(obj)
        % prob. ms used calc freq.
        obj.bigStr = {'\bfModel: NN Spline'};

        obj.smallStr = sprintf('---');
    end

    %***************************
    % plot fit
    %***************************
    function obj = plotFit(obj,haxes)
        if ~isempty( obj.fResult )
            dx = xlim(haxes);
            xrange = linspace(dx(1),dx(2),500);
            obj.handle = plot(haxes,xrange,obj.fResult(xrange), ...
                   'color',obj.plotColor,'linewidth',1.5);
        end
    end


%***************************
% runFit
%***************************
function obj = runFit(obj, seqObj, haxes)

    % get data
    xdata = [];
    ydata = [];
	for i=1:seqObj.numData
        if obj.dataSet(i) && seqObj.listData{i}.numSelPoints > 0
            xdata = [xdata; seqObj.listData{i}.selectedData(:,2)];
            ydata = [ydata; seqObj.listData{i}.selectedData(:,3)];
        end
    end

    % check datasize
    if size(xdata,1)<obj.minPoints
        disp('Datasize too small.');
        return;
    end
    
    % calc mean
    avData = mgroup([ xdata, ydata,  ydata],['mean';'stdd']);
    
    try 
        [obj.fResult,obj.gof] = fit( avData(:,1), avData(:,2), obj.fType, obj.fOpts{1});
        obj = obj.createOutput;
    catch
        disp(['Problems during fiting']);
        disp(lasterr);
        disp('');
    end

end

end
end
