classdef fitThreeBody < fitClass
% Elmar, 04.9.2008





methods


%*********************************
% Init fitting stuff
% initiate what ever is 
% needed
%*********************************
    function obj = initFitting(obj)
            % init fit
            obj.fType    = fittype(['n0/sqrt(1+2*n0^2*k3*t)'], ...
                'independent', 't', ...
                'dependent',   {'k3','n0'} );
            obj.fOpts{1}  = fitoptions('Method','NonlinearLeastSquares','Algorithm','Levenberg-Marquardt');
            obj.fitName   = 'ThreeBody';  % internal name
            obj.minPoints = 3;              % minimum number of datapoints
        end


%*********************************
% init prepoints
% calculate the prepoints
% for the first time
% (just from min/max of axes)
%*********************************
function obj = startPrePoints(obj, haxes)
    dx = xlim(haxes);
    dy = ylim(haxes);
    x  = [dx(1) dx(1)] + abs(dx(2)-dx(1))*[0.1 0.9];
    y  = [dy(1) dy(1)] + abs(dy(2)-dy(1))*[0.9 0.1];
    obj.prePoints(1,:) = [x(1) y(1)];
    obj.prePoints(2,:) = [x(2) y(2)];
end

%*********************************
% calc the start parameters for 
% fit. Either from prePoints
% or take them from the last fit.
%*********************************
function obj = getStartPoints(obj,haxes)
    
    if obj.adoptPoints && ~isempty(obj.fResult)
        obj.fOpts{1}.StartPoint = [obj.fResult.k3 obj.fResult.n0];
    else
        % start points [p1 p2], from prepoints
         if isempty(obj.prePoints)
              obj = obj.startPrePoints(haxes);
         end
         y2 = obj.prePoints(2,2);
         x2 = obj.prePoints(2,1);
         y1 = obj.prePoints(1,2);
         x1 = obj.prePoints(1,1);
         n0 = sqrt( y2^2- y2^2*x2/x1) / sqrt( 1-y2^2*x2/y1^2/x1);
         k3 = abs( (n0^2-y1^2 )/(3*n0*y1^2*x1) );
         obj.fOpts{1}.StartPoint = [k3 n0];
%         obj.fOpts{1}.Upper = [1e-5 Inf];
%         obj.fOpts{1}.Lower = [1e-14 0];         
        % obj.fOpts{1}.StartPoint = [1e-5 10];
         obj.fOpts{1}.Upper = [Inf n0*n0];
         obj.fOpts{1}.Lower = [0 n0*0.1];         

    end
end

%******************************************
% calc fit function for given
% prePoints (for dashed line on plot)
%******************************************
function [xrange,yrange] = calcDataPoints(obj,xrange,prePoints)
         y2 = obj.prePoints(2,2);
         x2 = obj.prePoints(2,1);
         y1 = obj.prePoints(1,2);
         x1 = obj.prePoints(1,1);
         
         n0 = sqrt( y2^2- y2^2*x2/x1) ./ sqrt( 1-y2^2*x2/y1^2/x1);
         k3 = (n0^2-y1^2 )/(3*n0*y1^2*x1);
         yrange = n0./sqrt(1+n0*3*k3*xrange);
end

%******************************************
% calc prePoints from old fit results
% (to set new prePoints)
%******************************************
function obj = last2PrePoints(obj, haxes)
    if isempty(obj.fResult)
        obj = obj.startPrePoints(haxes);
        return;
    end
    dx = xlim(haxes);
    dy = ylim(haxes);
    x  = [dx(1) dx(1)] + abs(dx(2)-dx(1))*[0.1 0.9];
    y = obj.fResult.n0./sqrt(1+obj.fResult.n0*3*obj.fResult.k3*x);
    obj.prePoints(:,1) = x;
    obj.prePoints(:,2) = y;
end


%***************************************
% write output to strings
% bigStr - is fit function given in 
% extra widget
% smallStr - is string in gui
%***************************************
function obj = createOutput(obj)
    fCoeffs = coeffvalues(obj.fResult);
    fSigma  = confint(obj.fResult);
    deltaN0 = max( abs(fSigma(:,2)- obj.fResult.n0) );
    deltaK3 = max( abs(fSigma(:,1)- obj.fResult.k3) );
    
    obj.bigStr = {'\bfModel: n0/(1+n0*3*K3*t)^0.5',...
                  '\rmno parameters unused'};
    obj.smallStr = sprintf('%-2.2e',obj.fResult.k3);
    obj.tabEntries = {'n0', num2str(obj.fResult.n0), num2str(deltaN0); ...
                      'K3', num2str(obj.fResult.k3), num2str(deltaK3); ...
                      '','','';...
                      'xi2',num2str(obj.gof.rsquare),''};
                  
    obj.fResult
end



end


end
